@@ -13,7 +13,7 @@ from mtmai.agents.nodes.hello_agent import (
 )
 from mtmai.agents.nodes.qa_node import QaNodeRequest, QaNodeResult, node_qa
 from mtmai.chainlit.context import context
-from mtmai.core.db import get_async_session
+from mtmai.db.db import get_async_session
 from mtmai.core.logging import get_logger
 from mtmai.deps import AsyncSessionDep
 from mtmai.models.chat import ChatProfile
@@ -25,7 +25,7 @@ from mtmai.mtlibs.inputs.input_widget import TextInput, ThreadForm
 logger = get_logger()
 
 
-class PostGenAgent():
+class PostGenAgent:
     """
     前端站点的 “AI生成新文章”按钮，调用这个agent
     """
