@@ -1,13 +1,14 @@
+import json
 import re
+import uuid
 
-# together = Together()
+import orjson
+from json_repair import repair_json
+from langchain_core.messages import AIMessage, ToolCall
 from langgraph.checkpoint.memory import MemorySaver
 
 from mtmai.llm.llm import get_llm_chatbot_default
 
-# from together import Together
-
-
 memory = MemorySaver()
 
 
@@ -87,3 +88,48 @@ def clean_json_string(json_str: str) -> str:
     # 替换非法控制字符
     json_str = re.sub(r"[\x00-\x1f\x7f]", "", json_str)
     return json_str
+
+
+def fix_tool_calls(ai_msg: AIMessage):
+    if not ai_msg.content or (
+        ai_msg.tool_calls and ai_msg.tool_calls[0].type == "tool_call"
+    ):
+        # 已是正确格式
+        return ai_msg
+    # 情况1： 以lamma3.1 常见的 <function> 格式回复函数函数调用
+    function_regex = r"<function=(\w+)>(.*?)</function>"
+    match = re.search(function_regex, ai_msg.content, re.DOTALL)
+    if match:
+        function_name, args_string = match.groups()
+
+        args = json.loads(args_string)
+        ai_msg.tool_calls.append(
+            ToolCall(
+                name=function_name,
+                arguments=args,
+                id=str(uuid.uuid4()),
+                type="tool_call",
+            )
+        )
+        ai_msg.content = ""
+        return ai_msg
+
+    # 情况2 函数调用没有出现在 tool_calls 字段，而是出现在 content 中，json格式
+    # 例子： {"name": "ToDevelopAssistant", "parameters": {"request": "I want to edit an article"}}
+    loaded_data = orjson.loads(repair_json(ai_msg.content))
+    if (
+        isinstance(loaded_data, dict)
+        and "name" in loaded_data
+        and "parameters" in loaded_data
+    ):
+        ai_msg.tool_calls.append(
+            ToolCall(
+                name=loaded_data["name"],
+                arguments=loaded_data["parameters"],
+                id=str(uuid.uuid4()),
+                type="tool_call",
+            )
+        )
+        ai_msg.content = ""
+        return ai_msg
+    return ai_msg
