@@ -2,16 +2,12 @@
 博客系统api
 """
 
-from fastapi import APIRouter, Depends, HTTPException, Query
-from sqlmodel import Session, select
+from fastapi import APIRouter, HTTPException, Query
+from sqlmodel import select
 
-from mtmai.core.db import get_session
-from mtmai.crud.curd_blog import create_blog_post, get_tags_by_post, update_post
+from mtmai.crud.curd_blog import get_tags_by_post, update_post
 from mtmai.deps import AsyncSessionDep
-from mtmai.flows.article_gen import flow_article_gen
 from mtmai.models.blog import (
-    BlogPostCreateReq,
-    BlogPostCreateResponse,
     BlogPostDetailResponse,
     BlogPostItem,
     BlogPostListResponse,
@@ -28,7 +24,7 @@ router = APIRouter()
 @router.get("/posts", response_model=BlogPostListResponse)
 async def post_list(
     *,
-    db: Session = Depends(get_session),
+    db: AsyncSessionDep,
     query: str = Query(default=""),
     offset: int = 0,
     limit: int = Query(default=100, le=100),
@@ -59,8 +55,8 @@ async def post_list(
             .offset(offset)
             .limit(limit)
         )
-
-    results = db.exec(joined_query).all()
+    result = await db.exec(joined_query)
+    results = result.all()
 
     posts = [
         BlogPostItem(
@@ -76,13 +72,13 @@ async def post_list(
     return BlogPostListResponse(data=posts, count=len(posts))
 
 
-@router.post("/", response_model=BlogPostCreateResponse)
-async def post_create(
-    *,
-    db: AsyncSessionDep,
-    req: BlogPostCreateReq,
-):
-    return await create_blog_post(session=db, blog_post_create=req)
+# @router.post("/", response_model=BlogPostCreateResponse)
+# async def post_create(
+#     *,
+#     db: AsyncSessionDep,
+#     req: BlogPostCreateReq,
+# ):
+#     return await create_blog_post(session=db, blog_post_create=req)
 
 
 @router.put("/{post_id}", response_model=BlogPostUpdateResponse)
@@ -136,10 +132,10 @@ async def get_post(
     )
 
 
-@router.post("/post_test1")
-async def post_test1(
-    *,
-    db: AsyncSessionDep,
-):
-    result = await flow_article_gen()
-    return result
+# @router.post("/post_test1")
+# async def post_test1(
+#     *,
+#     db: AsyncSessionDep,
+# ):
+#     result = await flow_article_gen()
+#     return result
