@@ -1,17 +1,15 @@
 import asyncio
 import json
-import logging
-import os
 import pprint
-import random
 import threading
-from datetime import datetime, timedelta
 from typing import Callable
 
 from fastapi import APIRouter
+import structlog
 
 router = APIRouter()
-logger = logging.getLogger()
+LOG = structlog.get_logger()
+
 
 
 counter = 0
@@ -46,98 +44,94 @@ class DemoTaskRunner:
                 self.streamer(f"0:{json.dumps({'task_id': i})}\n")
 
 
-dbFile = ".vol/demo_users.db"
+# dbFile = ".vol/demo_users.db"
 
 
+# def initMysqlLiteDb():
+#     import sqlite3
 
-def initMysqlLiteDb():
-    import sqlite3
+#     # 连接到SQLite数据库（如果不存在则创建）
+#     if os.path.exists(dbFile):
+#         print("删除旧数据库", dbFile)
+#         os.remove(dbFile)
 
-    # 连接到SQLite数据库（如果不存在则创建）
-    if os.path.exists(dbFile):
-        print("删除旧数据库", dbFile)
-        os.remove(dbFile)
+#     if not os.path.exists(".vol"):
+#         os.mkdir(".vol")
+#     conn = sqlite3.connect(dbFile)
+#     cursor = conn.cursor()
 
-    if not os.path.exists(".vol"):
-        os.mkdir(".vol")
-    conn = sqlite3.connect(dbFile)
-    cursor = conn.cursor()
+#     # 创建用户表
+#     cursor.execute("""
+#     CREATE TABLE IF NOT EXISTS users (
+#         id INTEGER PRIMARY KEY,
+#         name TEXT NOT NULL,
+#         age INTEGER,
+#         email TEXT UNIQUE,
+#         registration_date DATE,
+#         last_login DATETIME
+#     )
+#     """)
 
-    # 创建用户表
-    cursor.execute("""
-    CREATE TABLE IF NOT EXISTS users (
-        id INTEGER PRIMARY KEY,
-        name TEXT NOT NULL,
-        age INTEGER,
-        email TEXT UNIQUE,
-        registration_date DATE,
-        last_login DATETIME
-    )
-    """)
+#     # 生成示例数据
+#     names = [
+#         "Alice",
+#         "Bob",
+#         "Charlie",
+#         "David",
+#         "Eva",
+#         "Frank",
+#         "Grace",
+#         "Henry",
+#         "Ivy",
+#         "Jack",
+#         "Liang",
+#         "Boci",
+#         "Zhang",
+#     ]
+#     domains = [
+#         "gmail.com",
+#         "yahoo.com",
+#         "hotmail.com",
+#         "example.com",
+#         "example2.com",
+#         "example3.com",
+#     ]
 
-    # 生成示例数据
-    names = [
-        "Alice",
-        "Bob",
-        "Charlie",
-        "David",
-        "Eva",
-        "Frank",
-        "Grace",
-        "Henry",
-        "Ivy",
-        "Jack",
-        "Liang",
-        "Boci",
-        "Zhang",
-    ]
-    domains = [
-        "gmail.com",
-        "yahoo.com",
-        "hotmail.com",
-        "example.com",
-        "example2.com",
-        "example3.com",
-    ]
+#     for i in range(20):  # 创建50个用户记录
+#         name = random.choice(names)
+#         age = random.randint(18, 70)
+#         email = f"{name.lower()}{random.randint(1, 100)}@{random.choice(domains)}"
+#         registration_date = datetime.now() - timedelta(days=random.randint(1, 1000))
+#         last_login = registration_date + timedelta(days=random.randint(1, 500))
 
-    for i in range(20):  # 创建50个用户记录
-        name = random.choice(names)
-        age = random.randint(18, 70)
-        email = f"{name.lower()}{random.randint(1, 100)}@{random.choice(domains)}"
-        registration_date = datetime.now() - timedelta(days=random.randint(1, 1000))
-        last_login = registration_date + timedelta(days=random.randint(1, 500))
+#         cursor.execute(
+#             """
+#         INSERT INTO users (name, age, email, registration_date, last_login)
+#         VALUES (?, ?, ?, ?, ?)
+#         """,
+#             (name, age, email, registration_date.date(), last_login),
+#         )
 
-        cursor.execute(
-            """
-        INSERT INTO users (name, age, email, registration_date, last_login)
-        VALUES (?, ?, ?, ?, ?)
-        """,
-            (name, age, email, registration_date.date(), last_login),
-        )
+#     # 提交更改并关闭连接
+#     conn.commit()
+#     conn.close()
 
-    # 提交更改并关闭连接
-    conn.commit()
-    conn.close()
+#     print("Demo database 'demo_users.db' created successfully with sample data.")
 
-    print("Demo database 'demo_users.db' created successfully with sample data.")
-
-    # 函数用于显示表格内容
-    def display_table_contents():
-        conn = sqlite3.connect(dbFile)
-        cursor = conn.cursor()
-        cursor.execute("SELECT * FROM users LIMIT 5")
-        rows = cursor.fetchall()
-
-        print("\nSample data from the users table:")
-        for row in rows:
-            print(row)
-
-        conn.close()
-
-    display_table_contents()
+#     # 函数用于显示表格内容
+#     def display_table_contents():
+#         conn = sqlite3.connect(dbFile)
+#         cursor = conn.cursor()
+#         cursor.execute("SELECT * FROM users LIMIT 5")
+#         rows = cursor.fetchall()
 
+#         print("\nSample data from the users table:")
+#         for row in rows:
+#             print(row)
 
+#         conn.close()
 
+#     display_table_contents()
 
 
 # 定义使用的模型名称
@@ -252,5 +246,3 @@ async def run_conversation(user_prompt):
         )
         # 返回最终响应内容
         return second_response.choices[0].message.content
-
-
